@@ -19,7 +19,7 @@ $DB = "BADDB";
 $dbh = DBI->connect("dbi:DB2:$DB", "$USERID", "$PASSWORD", {PrintError => 0});
 check_value("CONNECT", "dbh", undef);
 check_value("CONNECT", "DBI::err", -1013);
-$expMsg = "[IBM][CLI Driver] SQL1013N  The database alias name or database name \"BADDB\" could not be found.  SQLSTATE=42705\n";
+expMsg = "[IBM][CLI Driver] SQL1531N  The connection failed because the name specified with the DSN connection string keyword could not be found in either the db2dsdriver.cfg configuration file or the db2cli.ini configuration file.  Data source name specified in the connection string: \"BADDB\".\n"
 check_value("CONNECT", "DBI::errstr", $expMsg);
 check_value("CONNECT", "DBI::state", "08001");
 
